@@ -1,10 +1,11 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-uniplate-1.6.12/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: uniplate
-version: 1.6.7
-id: uniplate-1.6.7-952017b8b36eba500d15313088618f3b
+version: 1.6.12
+id: uniplate-1.6.12-50c3d644c789ce0ffb7798228041d991
 
 license: BSD3
-copyright: Neil Mitchell 2006-2012
+copyright: Neil Mitchell 2006-2013
 maintainer: Neil Mitchell <ndmitchell@gmail.com>
 stability:
 homepage: http://community.haskell.org/~ndm/uniplate/
@@ -52,28 +53,27 @@ exposed-modules: Data.Generics.Str Data.Generics.Compos
                  Data.Generics.UniplateStrOn Data.Generics.Biplate
                  Data.Generics.PlateDirect Data.Generics.PlateTypeable
                  Data.Generics.PlateData
-hidden-modules: Data.Generics.PlateInternal
-                Data.Generics.Uniplate.Internal.Data
+hidden-modules: Data.Generics.Uniplate.Internal.Data
                 Data.Generics.Uniplate.Internal.DataOnlyOperations
                 Data.Generics.Uniplate.Internal.Utils
 trusted: False
-import-dirs: /usr/local/lib/ghc/uniplate-1.6.7
-library-dirs: /usr/local/lib/ghc/uniplate-1.6.7
-hs-libraries: HSuniplate-1.6.7
+import-dirs: /usr/local/lib/ghc/uniplate-1.6.12
+library-dirs: /usr/local/lib/ghc/uniplate-1.6.12
+hs-libraries: HSuniplate-1.6.12
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
-         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
-         hashable-1.1.2.3-1e9e274afb8e07dab57c2a975698461b
-         syb-0.3.7-a269c050536d4890f37a20513844e800
-         unordered-containers-0.1.4.6-3501841bb7a7f313c99e53e7965a1a02
+depends: base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
+         hashable-1.2.2.0-6aae2a5ae00dba4cc06a8e388409e9ed
+         syb-0.4.1-acd16ebc619c31f5db97bcd1e4196777
+         unordered-containers-0.2.4.0-2fd558fbd599b4e4c335e82ebd45f621
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-uniplate-1.6.7/html/uniplate.haddock
-haddock-html: /usr/local/share/doc/hs-uniplate-1.6.7/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-uniplate-1.6.12/html/uniplate.haddock
+haddock-html: /usr/local/share/doc/hs-uniplate-1.6.12/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
